function perf = autoreject( set_in, calib, plotag, applycalib, threshold1, threshold2 );
eegglobal;
retreiveset( set_in);

if nargin< 3
	plotag = 0;
end;
if nargin< 4
	applycalib = 0;
end;
if nargin > 5
	THRESHOLD(1) = threshold1;
	THRESHOLD(2) = threshold2;
end;

if applycalib 
	if iscell(ENTA) ENTA = ENTA{1}; end;
	[P R] =  matchcalib( calib, ENTA, plotag);
	ENTA = { ENTA P R };

	if iscell(ENTR) ENTR = ENTR{1}; end;
	[P R] =  matchcalib( calib, ENTR, plotag);
	ENTR = { ENTR P R };

	if iscell(KURTA) KURTA = KURTA{1}; end;
	[P R] =  matchcalib( calib, KURTA, plotag);
	KURTA = { KURTA P R };

	if iscell(KURTR) KURTR = KURTR{1}; end;
	[P R] =  matchcalib( calib, KURTR, plotag);
	KURTR = { KURTR P R };

	if iscell(KURTD) KURTD = KURTD{1}; end;
	[P R] =  matchcalib( calib, KURTD, plotag);
	KURTD = { KURTD P R };

	storeset( set_in );
end;

% reject or accept each component
% -------------------------------
txt = sprintf([ 'C = calibration value (0=accepted,1=rejected)\nA = algorithm (0=accepted,1=rejected)\n\nkd = kurtosis of topoplot\ngp = global signal measure\nka = kurtosis of accepted ' ...
		'trials\nkr = kurtosis of rejected trials\nea = entropy of accepted trials\ner = entropy of rejected trials\n\n'] );
txtmp = sprintf('                   \tC|A\tkd  \tgp  \t(ka  \tkr  \tea  \ter  )\n               ------------------------------------------------\n');
txt = [ txt txtmp ];
for index = 1:size(SIGNAL,1)
	% global proba for signal
	% -----------------------		
	P = KURTA{2}; TMPVAL = KURTA{1}; prob1 = P(1)* TMPVAL(index) + P(2); if prob1 < 0 prob1=0; end; if prob1 > 1 prob1=1; end;	
	P = KURTR{2}; TMPVAL = KURTR{1}; prob2 = P(1)* TMPVAL(index) + P(2); if prob2 < 0 prob2=0; end; if prob2 > 1 prob2=1; end;	
	P = ENTA {2}; TMPVAL = ENTA {1}; prob3 = P(1)* TMPVAL(index) + P(2); if prob3 < 0 prob3=0; end; if prob3 > 1 prob3=1; end;	
	P = ENTR {2}; TMPVAL = ENTR {1}; prob4 = P(1)* TMPVAL(index) + P(2); if prob4 < 0 prob4=0; end; if prob4 > 1 prob4=1; end;	
	globalproba = ( prob1 + prob2 + prob3 + prob4 ) / 4;
	
	% proba for channel distribution
	% ------------------------------
	P = KURTD{2}; TMPVAL = KURTD{1}; distproba = (P(1)* TMPVAL(index) + P(2)); 
	if distproba < 0 distproba=0; end; if distproba > 1 distproba=1; end;	

	TMPREJECT( index ) = 0;
	if 	globalproba > THRESHOLD(2) TMPREJECT( index ) = 1; end;
	if 	distproba   > THRESHOLD(3) TMPREJECT( index ) = 1; end;

	if isempty(calib) tmpp = -1; else tmpp = calib(index); end;  
	txtmp = sprintf('component %2d\t%d|%d\t%2.2f\t%2.2f\t(%2.2f\t%2.2f\t%2.2f\t%2.2f)\n', index, tmpp, TMPREJECT( index ), distproba, globalproba,  prob1, prob2, prob3, prob4 );
	txt = [ txt txtmp ];
end;
txtmp = sprintf('\n%d/%d components rejected (threshold for kd:%.2f; threshold for gp:%2.2f)\n', sum( TMPREJECT > 0 ), size(TMPREJECT(:),1), THRESHOLD(2), THRESHOLD(3)); 
txt = [ txt txtmp ];

% compare with original distribution or save
% ------------------------------------------
if ~isempty(calib) | applycalib
	perf = 100*sum( calib == TMPREJECT) / size(TMPREJECT(:),1);
	txtmp = sprintf('In comparison with the current rejection, the automatic rejection is %2.2f percents correct\n', 100*sum( (calib>0) == TMPREJECT )/ size(TMPREJECT(:),1)); 	
	txt = [ txt txtmp ];
	txtmp = sprintf('Modification not saved\n');
	txt = [ txt txtmp ];
else
	perf = 0;
	COMPREJECT = TMPREJECT;
	txtmp = sprintf('Modification applyed and saved\n');
	txt = [ txt txtmp ];
end;			

fprintf('%s', txt);
if plotag
	helpdlg( txt, 'Component rejection results');
end;

storeset(set_in);
return;