% channelentropy() - compute entropy for one or several channels
%                    (no trial consideration)
%
% Usage:
%   >> [entropy] = channelentropy( signal );
%
% Inputs:
%   signal     - 2D OR 3D signal, first dimention is the channels
%
% Outputs:
%   entropy    - entropy for each channel, to get the total entropy
%                of the signal, just sum over channels (if independant)

% arno@salk.edu, Arnaud Delorme, CNL / Salk Institute, 15 March 2001

% This program is free software; you can redistribute it and/or
% modify it.  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

function entropyCompo = channelentropy( signal );

if nargin < 1
	help channelentropy;
	return;
end;

counter = 0;
for rc = 1:size(signal,1)

	% COMPUTE THE DENSITY FUNCTION
	% ----------------------------
	[ dataProba sortbox ] = realproba( signal(rc, :), 1000 );

	% remove the zeros
	% ----------------
	indexes = find( sortbox ~= 0);
	sortbox = sortbox( indexes );	
	
	% compute entropy
	% ---------------
	entropyCompo(rc) = - sum(size(signal,2) * sortbox .* sortbox .* log( sortbox ));

end;		
return;
	