% [cor] = crosscor(X, Y);
%
% Compute crosscorelation of two vector variables X and Y of the same size.
% X and Y are 1 diemtionnal vector, the 2nd dimention can be defined by
% the frame option.
% X and Y can also be 2 dimentionnal arrays. The correlation is compute for
% pair of rows and then averaged.
% Results are place into corrlation matrix cor. 
%
% [cor, meanX, meanY ] = crosscor(X, Y, timerange, frames, newframes);
%
% Expanded version. Mean matrices meanX and meanY are computed.
% If frame is the size of X and Y then meanX=X and meanY = Y.
%
% optionnal parameters:
%   timerange : [min max] time variable for X and Y
%   frames : integer, to compute individual crosscorelation between X and Y trials
%            X and Y are divided into several trial of size frame
%            default -> size of X and Y			
%   newframes : array of integer designating the frames to take into account
%               for subsampling or to plot only a part of the full diagram
%               default -> [1:frames]

% arno@salk.edu, Arnaud Delorme, CNL / Salk Institute, 
% orignal version: March 2001

% This program is free software; you can redistribute it and/or
% modify it.  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

function [ corr2, meanX, meanY ] = crosscor(X, Y, timerange, frames, newframes);

MARGIN          = 0.12;         % width of marginal plots
LINEWIDTH       = 2;
AXES_FONT       = 10;

if nargin < 2
	help crosscor;
	return;
end;
if nargin < 3
	timerange = [1 size(X,2)];
end;
if nargin < 4
	frames = 1;
end;
if nargin < 5
	newframes = [1:frames];
end;

if size(X,1) ~= 0
    XX = X';
    X  =X(:)';
end;     
if size(Y,1) ~= 0
    YY = Y';
    Y  = Y(:)';
end;     
if size(X,2) ~= size(Y,2)
    error('The two inpout must be the same size');
end;     

% -----------------------
% reorganise the matrixes
% -----------------------
indexesX = [1:frames:size(X,2)];
indexesY = [1:frames:size(Y,2)];
sweepsX = size(X,2)/frames;
sweepsY = size(Y,2)/frames;
newX      = zeros(size(newframes,2), sweepsX);
newY      = zeros(size(newframes,2), sweepsY);
nbFrame   = 1;
CrossCor  = zeros(size(newframes,2), size(newframes,2));

for index = newframes
		tmpindexesX = indexesX+index-1;
		tmpindexesY = indexesY+index-1;
		newX(nbFrame,:) = newX(nbFrame,:) + X(tmpindexesX);
		newY(nbFrame,:) = newY(nbFrame,:) + Y(tmpindexesX);
		nbFrame = nbFrame+1;
end;
for indexX=1:sweepsX
	CrossCor = CrossCor + newX(:,indexX)*newY(:,indexX)'/sweepsX;
end;	

meanX = mean(newX,2);
meanY = mean(newY,2);

% -----------------------------------
% compute the individual correlations with the C program
% -----------------------------------
%tmp = newX';
%save -ascii 'X' tmp;
%tmp = newY';
%save -ascii 'Y' tmp;
%fprintf('Running the C program: %d sweeps (first var) %d sweeps (second var) and %d frames\n', sweepsX, sweepsY, nbFrame-1);
%reply = questdlg( 'Ready ?', '', 'Yes');
%load -ascii 'RES'
%command = sprintf('!/home/arno/fam2/eeg/matlabfunc/crosscorr %d %d %d %d', sweepsX, sweepsY, nbFrame-1, -1); % 10 is the baseline
%eval( command );

% ------------------
% color init ploting
% ------------------
ybase = 0.0;
subheight = 0.9;
set(gcf,'DefaultAxesFontSize',AXES_FONT)
colormap(jet(256));
pos = get(gca,'position'); % plot relative to current axes
q = [pos(1) pos(2) 0 0];
s = [pos(3) pos(4) pos(3) pos(4)];
axis('off')

h(6) = axes('Units','Normalized',...
               'Position',[MARGIN ybase+MARGIN 0.9-MARGIN subheight].*s+q);

map=hsv(300); % install circular color map - green=0, yellow, orng, red, violet = max
              %                                         cyan, blue, violet = min
map = flipud([map(251:end,:);map(1:250,:)]);
map(151,:) = map(151,:)*0.9; % tone down the (0=) green!
colormap(map);

% -----------------------
% plot these correlations
% -----------------------
RES = CrossCor;
%load -ascii RES
mat = gauss2d(5, 5, 1, 1);
corr2 = RES;
%corr2 = corr2-meanX * meanY';
corr2 = conv2(corr2, mat, 'same');
realtimerange = linspace( timerange(1), timerange(end), size(corr2,2));
imagesc( realtimerange, realtimerange, corr2);

%surf(realtimerange, realtimerange,RES);
%axis([ timerange(1), timerange(end), timerange(1), timerange(end)] );
tmpax = caxis;
caxis([-max(abs(tmpax)) max(abs(tmpax))]);
%shading interp;
d = line([ 0 0], [ timerange(1) timerange(end)]); set(d, 'Color', [0 0 0 ]); 
d= line([ timerange(1) timerange(end)], [0 0]); set(d, 'Color', [0 0 0 ]);
d= line([ timerange(1) timerange(end)], [ timerange(1) timerange(end)]); set(d, 'Color', [0 0 0 ]); set(d, 'LineStyle', '- -');
ytl = get(h(6), 'YTickLabel');
set(h(6), 'YTickLabel' , []);
set(h(6), 'XTickLabel' , []);
%set(h(6), 'YDir', 'normal');
%set(h(6), 'YTickLabel' , ytl);
set(h(6), 'Ydir', 'normal');
grid on;
set(h(6), 'XTickMode', 'manual');
set(h(6), 'XTick', linspace( timerange(1), timerange(end), 11)); 
set(h(6), 'YTickMode', 'manual');
set(h(6), 'YTick', linspace( timerange(1), timerange(end), 11));
%cc  = get(h(6), 'XTickLabel');
%set(h(6), 'YTickLabel', cc);

% -----------------------
% plot these correlations
% -----------------------

%h(8) = axes('Position',[.92 ybase+MARGIN .05 subheight].*s+q);
h(10) = axes('Units','Normalized','Position',[MARGIN ybase 0.9-MARGIN MARGIN].*s+q); 
plot(realtimerange, meanY,'LineWidth',LINEWIDTH);
tick = get(h(10),'YTick');
set(h(10), 'XLim',[ timerange(1), timerange(end)]);
set(h(10),'YTick',[tick(1) ; tick(length(tick))])
set(h(10),'YAxisLocation','right')
midpos = get(h(10),'Position');
%if nargout<6
 xlabel('Time (ms)')
%end
ylabel('mv')

%
% Plot mean baseline coherence at each freq on left side of image
%
h(11) = axes('Units','Normalized','Position',[0 ybase+MARGIN MARGIN subheight].*s+q);
plot(realtimerange, meanX,'LineWidth',LINEWIDTH); % plot mbase
tick = get(h(11),'YTick');
set(h(11), 'XLim', [timerange(1), timerange(end)]);
set(h(11),'YTick',[tick(1) ; tick(length(tick))])
set(h(11),'View',[90 90])
xlabel('Component')
%ylabel('Component')
set(h(11), 'Xdir', 'reverse');
ylabel('mv')

%cbar(h(8),151:300,[0 coh_caxis(2)]); % use only positive colors (gyorv) 
%                                      for coherences
%
% Plot delta-mean min and max coherence at each time point on bottom of image
%

return;
