% [gradX, gradY ] = gradmap( map, filename, draw )
% 
% compute the gradient of an EEG distribution
%
% Inputs:
%    map      - level of activity (size: nbelectrodes * nbChannel)
%    filename - filename (.loc file) countaining the coordinates
%               of the electrodes, or array countaining complex positions 		 
%    draw     - integer, if not nul draw the gradient (default:0)
%
% Output:
%    gradX, gradY - gradient over X and Y (use cart2pol to get amplitude and 

%
%  This section bastardizes topoplot.m in order to get gradient maps
%  for all of the component maps brought back from ClusMapSpec.m
%  This is done to improve the clustering results.
%

% arno@salk.edu, Arnaud Delorme, CNL / Salk Institute, 2001
% adapted from a version by Scott Makeig et Marissa Wicklein

% This program is free software; you can redistribute it and/or
% modify it.  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

function [gradx, grady] = gradmap( map, filename, draw ) 

if nargin < 2
	help gradmap;
	return;
end;

MAXCHANS = size(map,1);
GRID_SCALE = 2*MAXCHANS+5;

% Read the channel file
% ---------------------
if isstr( filename )
	fid = fopen(filename); 
	locations = fscanf(fid,'%d %f %f %s',[7 MAXCHANS]);
	fclose(fid);
	locations = locations';
	Th = pi/180*locations(:,2);                               % convert degrees to rads
	Rd = locations(:,3);
	ii = find(Rd <= 0.5); % interpolate on-head channels only
	Th = Th(ii);
	Rd = Rd(ii);
	[x,y] = pol2cart(Th,Rd);
else
	x = real(filename);
	y = imag(filename);
end;	

% locates nearest position of electrod in the grid 
% ------------------------------------------------
xi = linspace(-0.5,0.5,GRID_SCALE);   % x-axis description (row vector)
yi = linspace(-0.5,0.5,GRID_SCALE);   % y-axis description (row vector)
for i=1:MAXCHANS
   [useless_var horizidx(i)] = min(abs(y(i) - xi));    % find pointers to electrode
   [useless_var vertidx(i)] = min(abs(x(i) - yi));     % positions in Zi
end;
   
% Compute gradient
% ----------------
for i=1:size(map,2) 
   	[Xi,Yi,Zi] = griddata(y,x,map(:,i),yi',xi, 'invdist');   % interpolate data
   	[FX,FY] = del2(Zi);
	positions = horizidx + (vertidx-1)*GRID_SCALE;

	gradx(:,i) = FX(positions(:));
	grady(:,i) = FY(positions(:));

	% Draw gradient
	% -------------
	if exist('draw');
		subplot(ceil(sqrt(size(map,2))), ceil(sqrt(size(map,2))), i);
		contour(imresize(Zi,0.5)); hold on
		quiver(imresize(FX, 0.5), imresize(FY, 0.5)); hold off
	end;
end;                                                       

return;

