% realproba() - compute the effective probability of the value 
%               in the sample
%
% Usage: 
%   >> [probaMap, probaDist ] = realproba( data, discret);
%
% Inputs:
%   data       - the data onto which compute the probability
%   discret    - discretisation factor (default: (size of data)/5)
%                if 0 base the computation on a Gaussian 
%                approximation of the data 
%
% Outputs:
%   probaMap   - the probabilities associated with the values
%   probaDist  - the probabilities distribution 

% arno@salk.edu, Arnaud Delorme, CNL / Salk Institute, March 2001

% This program is free software; you can redistribute it and/or
% modify it  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

function [ probaMap, sortbox ] = realproba( data, BOXES );

if nargin < 1
	help realproba;
	return;
end;
if nargin < 2
	BOXES = round(size(data,1)*size(data,2)/5);
end;	

if BOXES > 0
	% COMPUTE THE DENSITY FUNCTION
	% ----------------------------
	SIZE = size(data,1)*size(data,2);
	sortbox = zeros(1,BOXES);
	minimum =  min(data(:));
	maximum =  max(data(:));
	data = floor((data - minimum )/(maximum - minimum)*(BOXES-1))+1;
	for index=1:SIZE
		sortbox(data(index)) = sortbox(data(index))+1;
	end;
	probaMap = sortbox(data) / SIZE;
	sortbox  = sortbox / SIZE;
else
	% BASE OVER ERROR FUNCTION
	% ------------------------
	data     = (data-mean(data(:)))./std(data(:));
	probaMap = exp(-0.5*( data.*data ))/(2*pi);
	probaMap = probaMap/sum(probaMap); % because the total surface under a normalized Gaussian is 2
	sortbox  = probaMap/sum(probaMap);
end;
return;