% trialentropy() - compute the entropy of single trials
%
% Usage:
%   >>  [entropy, density] = trialentropy( signal, frames, threshold );
%
% Inputs:
%   signal     - one dimentionnal column vector of values of size 
%                sweeps*frames or two dimentional array of size 
%                channels x (sweeps*frames)
%   frames     - number of frames
%   threshold  - percentage of maximum entropy for removing bad sweeps 
%                (default:0.2)
%
% Outputs:
%   entropy    - entropy of the single trials (size sweeps)
%   density    - density array 

% arno@salk.edu, Arnaud Delorme, CNL / Salk Institute, 2001

% This program is free software; you can redistribute it and/or
% modify it.  
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

function [entropy, entropyMap] = trialentropy( signal, pnts, threshold );

if nargin < 2
	help trialentropy;
	return;
end;	
if nargin < 3
	threshold = 0.2;
end;	
sweeps = size(signal,2)/pnts;
entropy    = zeros(1,sweeps);

for rc = 1:size(signal,1)

	% COMPUTE THE DENSITY FUNCTION
	% ----------------------------
	[ dataProba sortbox ] = realproba( signal(rc, :), 1000 );

	% compute all entropy
	% ---------------
	for index=1:sweeps
		datatmp = dataProba((index-1)*pnts+1:index*pnts);
		entropy(index) = entropy(index) - sum( datatmp .* log( datatmp ) );
	end;
end;

% TAG the bad sweeps
% ------------------
entropyMap = zeros(pnts, sweeps);
threshold  = max(entropy) * threshold;
[A I] = find (entropy < threshold );
entropyMap(:,I) = ones(pnts, size(I,2));

%for index=1:sweeps
%	if entropy(index) < threshold
%		entropyMap(:,index) = ones(1, pnts);
%	end;
%end;
entropy = entropy';		
return;
