#include <stdio.h>
#include <stdlib.h>

/*---------------------------------------------

Standart formula for correlation is 

Cor(X, Y) = cov(X ,Y)/(sd(X)*sd(Y)) 
with cov(X,Y) = E{( X-E{X} )*( Y-E{Y} )}

The goal is to compute this correlation for each pair of point of 2 components for all trials

example of one pair

X = all trials of component 1 at time 100 ms
Y = all trials of component 2 at time 90  ms

We thus would have an array of correlation coefficient (of size frames*frames)

---------------------------------------------

I used this formula and the result is quite uninteresting.
Using this formula mean that we do not exploit the temporality in the data. 

I thus considered E{X}, E{Y}, sd(X) and sd(Y) to be constant whatever the time.
cov(X, Y) = E{( X-baseline )*( Y-baseline )} and Cor(X, Y) is proportionnal to cov(X, Y)

This formula is fine and lead to the type of crosscorrelogram I presented you in the lab meeting.
The problem is that deviation from baseline could be correlated but could also occur at chance if two components are statistically active at the same time. They might only be coactivated (/baseline) at the same time.

----------------------------------------------

In between these two extremes, I was thinking of taking time windows of about 50 ms to compute the mean and standart deviation. For each pair of 2 points of 2 components  

cov(X, Y) = E{( X-baseline(X+-25ms)*( Y-baseline(Y+-25ms) )} and 
Cor(X, Y) = cov(X ,Y)/(sd(X+-25ms)*sd(Y+-25ms))

Thus, any variation of this new coefficient would reflect real correlation and not coactivation.*/

#define FORMAT	float

int main (int argc, char **argv) {

int SWEEPSX = atoi(argv[1]);
int SWEEPSY = atoi(argv[2]);
int FRAMES = atoi(argv[3]);
int BASELINE = atoi(argv[4]);
// SWEEPS = lines
// FRAMES = columns

FILE *fx = fopen("X", "r");
FILE *fy = fopen("Y", "r");

if (!fx) { printf("Error opening file X\n"); exit(-1); }
if (!fy) { printf("Error opening file Y\n"); exit(-1); }

FORMAT *X = new FORMAT[SWEEPSX*FRAMES]; FORMAT *px = X;
FORMAT *Y = new FORMAT[SWEEPSY*FRAMES]; FORMAT *py = Y;

for (int i=0; i<SWEEPSX; i++)
  for (int j=0; j<FRAMES; j++) {
    fscanf(fx, "%f", px); px++; 
  }
for (int i=0; i<SWEEPSY; i++)
  for (int j=0; j<FRAMES; j++) {
    fscanf(fy, "%f", py); py++;
  }
printf("Files read\n");

// compute mean and std for real crosscorelation 
// ---------------------------------------------
FORMAT *sdx = new FORMAT[FRAMES];
FORMAT *sdy = new FORMAT[FRAMES];
if (BASELINE == -1) {	
	for (int i=0; i<FRAMES; i++) {
  		FORMAT mx = 0; 	
  		FORMAT my = 0; 	
		FORMAT sdxtmp = 0; 	
  		FORMAT sdytmp = 0; 	
  		px = X+i;
  		py = Y+i;	
  		for (int j=0; j<SWEEPSX ; j++) { mx+= *px; sdxtmp += *px* *px; px+=FRAMES; }
  		for (int j=0; j<SWEEPSY ; j++) { my+= *py; sdytmp += *py* *py; py+=FRAMES; }
  		mx /= SWEEPSX;
  		my /= SWEEPSY;
  		sdx[i]= sdxtmp / SWEEPSX - mx*mx;	
  		sdy[i]= sdytmp / SWEEPSY - my*my;		
  		px = X+i;
  		py = Y+i;	
  		for (int j=0; j<SWEEPSX; j++) { *px -= mx; px+=FRAMES; }
  		for (int j=0; j<SWEEPSY; j++) { *py -= my; py+=FRAMES; }
  	}	
}

// compute spacial baseline
// ------------------------
if (BASELINE > 0) {	
	FORMAT mx = 0; 	
	FORMAT my = 0; 
	for (int i=0; i<BASELINE; i++) {
	  px = X+i;
	  py = Y+i;	
	  for (int j=0; j<SWEEPSX ; j++) { mx+= *px; px+=FRAMES; }
	  for (int j=0; j<SWEEPSY ; j++) { my+= *py; py+=FRAMES; }
	}
	mx /= (SWEEPSX*BASELINE);
	my /= (SWEEPSY*BASELINE);
	for (int i=0; i<FRAMES; i++) {
  		px = X+i;
  		py = Y+i;	
  		for (int j=0; j<SWEEPSX; j++) { *px -= mx; px+=FRAMES; }
 		for (int j=0; j<SWEEPSY; j++) { *py -= my; py+=FRAMES; }
	}
}	

// compute crosscorllation
// -----------------------
FORMAT *cross = new FORMAT[FRAMES*FRAMES]; FORMAT *pc    = cross;
FORMAT *var   = new FORMAT[FRAMES*FRAMES]; FORMAT *pcvar = var;
for (int i=0; i<FRAMES*FRAMES; i++) { *pc= 0; pc++; *pcvar= 0; pcvar++; }

/* FOR BOOTSTRAP
  for (int ii=0; ii<SWEEPSX; ii++) {
  if (!(ii %10)) printf("%d\n", ii);
  for (int jj=0; jj<SWEEPSY; jj++) {

    pc    = cross;
	pcvar = var;
    px = X + ii*FRAMES;
 
    for (int i=0; i<FRAMES; i++) {
      py = Y + jj*FRAMES;

      for (int j=0; j<FRAMES; j++) {
      	FORMAT tmp = *px * *py;
		*pc += tmp;
		//*pcvar += tmp*tmp;
		//pcvar++;
		pc++;
		py++;
      }
      px++;
    }
  }
}*/

for (int ii=0; ii<SWEEPSX; ii++) {
    pc    = cross;
	pcvar = var;
    px = X + ii*FRAMES;
 
    for (int i=0; i<FRAMES; i++) {
      py = Y + ii*FRAMES;

      for (int j=0; j<FRAMES; j++) {
      	FORMAT tmp = *px * *py;
		*pc += tmp;
		//*pcvar += tmp*tmp;
		//pcvar++;
		pc++;
		py++;
      }
      px++;
   }
}

if (BASELINE < 0) {
	FORMAT nbcondition = SWEEPSX * SWEEPSY;
	FORMAT m, sigma;
	for (int i=0; i<FRAMES; i++) {
		for (int j=0; j<FRAMES; j++) {
			int offset = j+i*FRAMES;
			FORMAT m = cross[offset]/nbcondition;
			var[offset]   = var[offset]/nbcondition-m*m;

			cross[offset] = cross[offset]/(sdx[i]*sdy[j]);
			//var[i] = m/sqrt(var[i])*sqrt(nbcondition-1);
		}
	}	
}

FILE *fres = fopen("RES", "w");
FILE *fres2 = fopen("TIMEF", "w");
pc    = cross;
pcvar = var;
for (int i=0; i<FRAMES; i++) {
  for (int j=0; j<FRAMES; j++) {
    fprintf(fres, "%f\t", *pc);
    fprintf(fres2, "%f\t", *pcvar);
    pc++;
    pcvar++;
  }
  fprintf(fres, "\n");
  fprintf(fres2, "\n");
}
fclose( fres );
fclose( fres2 );
}


